#include "../nanolibs/nanoglut.c"
#include <math.h>

GLuint		triangle;

void
draw_setup(GLsizei width, GLsizei height)
{
	GLfloat 	aspect;
	glViewport(0, 0, width, height);
	aspect = (GLfloat) width / (GLfloat) height;
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glOrtho(-aspect, aspect, -1, 1, -1, 1);
	glMatrixMode(GL_MODELVIEW);
	glBlendFunc(GL_ONE, GL_ONE);
	triangle = glGenLists(1);
	glNewList(triangle, GL_COMPILE);
	glBegin(GL_TRIANGLES);
	glColor3f(.4f, 0, 0);
	glVertex2f(0, 1);
	glColor3f(0, .4f, 0);
	glVertex2f(-1, -1);
	glColor3f(0, 0, .4f);
	glVertex2f(1, -1);
	glEnd();
	glEndList();
	return;
}

void
draw(void)
{
	static GLfloat	phase = 0;
	GLfloat 	cl;
	cl = 0.5f * (GLfloat)(1 + sin(phase));
	glClearColor(cl, cl, cl, 1);
	glClear(GL_COLOR_BUFFER_BIT);
	glColor3f(1 - cl, 1 - cl, 1 - cl);
	glRectf(-0.5f, -0.5f, 0.5f, 0.5f);
	glEnable(GL_BLEND);
	glCallList(triangle);
	glPushMatrix();
	glScalef(1, -1, 1);
	glCallList(triangle);
	glPopMatrix();
	glDisable(GL_BLEND);
	phase += 0.02f;
}

void
draw_shutdown(void)
{
	glDeleteLists(triangle, 1);
}

int 
main(void)
{
	char *classes[] = {"no_event", "key_press", "key_release", "pointer_motion"};
	event_class_t ev_cls;
	int code, chr, px, py;
	if (!ref_init("demo1", 640, 480, 0, 0, 0, 0))
		return -1;
	draw_setup(640, 480);
	do {
		draw();
		ref_end_frame();
		ev_cls = ref_next_event(&code, &chr, &px, &py);
		if (ev_cls == no_event) {
			ref_delay(10);	/* limit idle FPS to 100 */
			continue;
		}
		printf("[%s]: CODE '%i', CHAR '%i' ('%c'), PX %i, PY %i\n",
			   classes[ev_cls], code, chr,
			   (chr >= 32) ? chr : ' ',
			   px, py);
	} while (code != key_escape);
	draw_shutdown();
	ref_shutdown();
	return 0;
}
